#
# spec file for package sqlite3
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Simplify building on RH for Application:Geo (SR#212812).
%define pname sqlite3
%define oname sqlite

Name:           %pname
Version:        3.8.10.2
Release:        11.3.1
%define tarversion 3081002
Summary:        Embeddable SQL Database Engine
License:        SUSE-Public-Domain
Group:          Productivity/Databases/Servers
Url:            http://www.sqlite.org/
#
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  unzip
%if 0%{?suse_version:1}
BuildRequires:  update-desktop-files
%endif
#
Requires:       libsqlite3-0 = %version
Provides:       %oname = %version
Obsoletes:      %oname < %version
Source0:        http://www.sqlite.org/2015/sqlite-autoconf-%tarversion.tar.gz
Source1:        baselibs.conf
Source2:        http://www.sqlite.org/2015/sqlite-doc-%tarversion.zip
Patch0:         sqlite3-CVE-2016-6153.patch
Patch1:         sqlite3-journal-file.patch
Patch2:         sqlite3-xFetch-null.patch
Patch3:         sqlite3-CVE-2018-20346.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      sqlite-64bit < %{version}
Provides:       sqlite-64bit = %{version}
%endif
#

%description
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is a server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.

%package -n libsqlite3-0

Summary:        Shared libraries for the Embeddable SQL Database Engine
Group:          Development/Libraries/C and C++

%description -n libsqlite3-0
This package contains the shared libraries for the Embeddable SQL
Database Engine.

SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is a server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.

%package devel

Summary:        Embeddable SQL Database Engine
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsqlite3-0 = %version
Provides:       %oname-devel = %version
Obsoletes:      %oname-devel < %version
Suggests:       %name-doc

%description devel
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server; SQLite is the server. The SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command-line tool or via any
application which supports the Qt database plug-ins.

%package doc

Summary:        Documentation for %name
Group:          Documentation
%if 0%{?suse_version} >= 1130
BuildArch:      noarch
%endif

%description doc

Contains HTML documentation for SQLite: SQL Syntax, C/C++ API and
other documentation found on sqlite.org. The files can be found in
%_docdir/%name-doc.

%prep
%setup -q -n sqlite-autoconf-%tarversion -a2
%patch0
%patch1
%patch2
%patch3
rm -v sqlite-doc-%{tarversion}/releaselog/current.html
ln -sv `echo %{version} | sed "s/\./_/g"`.html sqlite-doc-%{tarversion}/releaselog/current.html

%build
export CFLAGS="%optflags -DSQLITE_ENABLE_COLUMN_METADATA -DSQLITE_ENABLE_FTS4 -DSQLITE_ENABLE_UNLOCK_NOTIFY"
%configure --disable-static
make

%install
make install DESTDIR=%buildroot
rm %buildroot/%_libdir/*.la

%post -n libsqlite3-0 -p /sbin/ldconfig

%postun -n libsqlite3-0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
/usr/bin/sqlite3
%doc %_mandir/man1/*

%files -n libsqlite3-0
%defattr(-,root,root)
%_libdir/libsqlite*.so.*

%files devel
%defattr(-,root,root)
/usr/include/*.h
%_libdir/libsqlite*.so
%_libdir/pkgconfig/sqlite3.pc

%files doc
%defattr(-,root,root)
%doc sqlite-doc-%tarversion/*

%changelog
* Fri Mar 15 2019 Reinhard Max <max@suse.com>
- CVE-2018-20346, bsc#1119687, sqlite3-CVE-2018-20346.patch:
  Fix remote code execution vulnerability in FTS3 (Magellan).
* Tue Apr  4 2017 max@suse.com
- Avoid calling sqlite3OsFetch() on a file-handle for which the
  xFetch method is NULL (bsc#1025034, sqlite3-xFetch-null.patch).
* Mon Jan 16 2017 max@suse.com
- Fix a segfault in the in-memory journal logic (bsc#1019518,
  sqlite3-journal-file.patch).
* Tue Jul  5 2016 max@suse.com
- Fix Tempdir Selection Vulnerability (bsc#987394, CVE-2016-6153,
  sqlite3-CVE-2016-6153.patch).
* Tue Aug 11 2015 max@suse.com
- Submit Factory package to SLE12-SP1 to enable the unlock notify
  API (fate#317928).
* Sun May 24 2015 astieger@suse.com
- SQLite 3.8.10.2:
  * Fix an index corruption issue introduced by version 3.8.7.
* Sun May 10 2015 astieger@suse.com
- SQLite 3.8.10.1:
  * Make sqlite3_compileoption_used() responsive to the
    SQLITE_ENABLE_DBSTAT_VTAB compile-time option.
  * Fix minor issues with the dbstat virtual table.
* Thu May  7 2015 crrodriguez@opensuse.org
- Update to SQLite 3.8.10
  * Added the y format string to the matchinfo() function of FTS3.
  * Performance improvements for ORDER BY, VACUUM, CREATE INDEX,
  PRAGMA integrity_check, and PRAGMA quick_check
  * Fix many obscure problems discovered while SQL fuzzing.
  * Add the ".binary" and ".limits" commands to the command-line shell
  * Make the "dbstat" virtual table part of standard builds
  when compiled with the SQLITE_ENABLE_DBSTAT_VTAB option.
* Wed Apr  8 2015 astieger@suse.com
- Update to SQLite 3.8.9:
  * Added the sqlite3_status64() interface.
  * Fix memory size tracking so that it works even if SQLite uses
    more than 2GiB of memory.
  * Added the PRAGMA index_xinfo command.
  * Fix a potential 32-bit integer overflow problem in the
    sqlite3_blob_read() and sqlite3_blob_write() interfaces.
  * Ensure that prepared statements automatically reset on extended
    error codes of SQLITE_BUSY and SQLITE_LOCKED even when
    compiled using SQLITE_OMIT_AUTORESET.
  * Correct miscounts in the sqlite3_analyzer.exe utility related
    to WITHOUT ROWID tables.
  * Added the ".dbinfo" command to the command-line shell.
  * Improve the performance of fts3/4 queries that use the
    OR operator and at least one auxiliary fts function.
  * Fix a bug in the fts3 snippet() function causing it to omit
    leading separator characters from snippets that begin with the
    first token in a column.
* Wed Feb 25 2015 mpluskal@suse.com
- Update to SQLite 3.8.8.3
  * Fix a bug (ticket 2326c258d02ead33) that can lead to incorrect
    results if the qualifying constraint of a partial index
    appears in the ON clause of a LEFT JOIN.
  * Added the ability to link against the "linenoise" command-line
    editing library in unix builds of the command-line shell.
* Thu Feb 12 2015 astieger@suse.com
- SQLite 3.8.8.2:
  * Enhance sqlite3_wal_checkpoint_v2(TRUNCATE) interface so that
    it truncates the WAL file even if there is no checkpoint work
    to be done.
* Tue Jan 20 2015 andreas.stieger@gmx.de
- SQLite 3.8.8.1:
  * Fix a bug in the sorting logic, present since version 3.8.4,
    that can cause output to appear in the wrong order on queries
    that contains an ORDER BY clause, a LIMIT clause, and that have
    approximately 60 or more columns in the result set.
* Fri Jan 16 2015 andreas.stieger@gmx.de
- SQLite 3.8.8
- New Features:
  * Added the PRAGMA data_version command
  * Added the SQLITE_CHECKPOINT_TRUNCATE option to the
    sqlite3_wal_checkpoint_v2() / PRAGMA wal_checkpoint.
  * Added the sqlite3_stmt_scanstatus() when compiled with
    SQLITE_ENABLE_STMT_SCANSTATUS.
  * The sqlite3_table_column_metadata() is enhanced to work
    correctly on WITHOUT ROWID tables and to check for the
    existence of a a table if the column name parameter is NULL.
    The interface is now also included in the build by default,
    without requiring the SQLITE_ENABLE_COLUMN_METADATA compile-
    time option.
  * Added the SQLITE_ENABLE_API_ARMOR compile-time option.
  * Added the SQLITE_REVERSE_UNORDERED_SELECTS compile-time option.
  * Added the SQLITE_SORTER_PMASZ compile-time option and
    SQLITE_CONFIG_PMASZ start-time option.
  * Added the SQLITE_CONFIG_PCACHE_HDRSZ option to sqlite3_config()
  * The number of rows in a VALUES clause is no longer limited by
    SQLITE_LIMIT_COMPOUND_SELECT.
  * Added the eval.c loadable extension that implements an eval()
    SQL function that will recursively evaluate SQL.
- Performance Enhancements:
  * Reduce the number of memcpy() operations involved in balancing a
    b-tree, for 3.2%% overall performance boost.
  * Improvements to cost estimates for the skip-scan optimization.
  * The automatic indexing optimization is now capable of
    generating a partial index if that is appropriate.
- Bug fixes:
  * Ensure durability following a power loss with "PRAGMA
    journal_mode=TRUNCATE" by calling fsync() right after
    truncating the journal file.
  * The query planner now recognizes that any column in the right-
    hand table of a LEFT JOIN can be NULL, even if that column has
    a NOT NULL constraint. Avoid trying to optimize out NULL tests
    in those cases.
  * Make sure ORDER BY puts rows in ascending order even if the
    DISTINCT operator is implemented using a descending index.
  * Fix data races that might occur under stress when running with
    many threads in shared cache mode where some of the threads are
    opening and closing connections.
  * Fix obscure crash bugs found by american fuzzy lop.
- Other changes:
  * Disable the use of the strchrnul() C-library routine unless it
    is specifically enabled using the -DHAVE_STRCHRNULL compile-
    time option.
  * Improvements to the effectiveness and accuracy of the
    likelihood(), likely(), and unlikely() SQL hint functions.
* Thu Dec 11 2014 andreas.stieger@gmx.de
- SQLite 3.8.7.4:
  * Bug fix: Add in a mutex that was omitted from the previous
    release.
* Sat Dec  6 2014 andreas.stieger@gmx.de
- SQLite 3.8.7.3:
  * Ensure the cached KeyInfo objects (an internal abstraction not
    visible to the application) do not go stale when operating in
    shared cache mode and frequently closing and reopening some
    database connections while leaving other database connections
    on the same shared cache open continuously.
  * Recognize that any column in the right-hand table of a LEFT
    JOIN can be NULL even if the column has a NOT NULL constraint.
    Do not apply optimizations that assume the column is never
    NULL.
* Wed Nov 19 2014 andreas.stieger@gmx.de
- SQLite 3.8.7.2:
  * Enhance the ROLLBACK command so that pending queries are
    allowed to continue as long as the schema is unchanged.
  * Bug fix: Make sure that NULL results from OP_Column are fully
    and completely NULL and do not have the MEM_Ephem bit set.
  * Bug fix: The %%c format in sqlite3_mprintf() is able to handle
    precisions greater than 70.
  * Bug fix: Do not automatically remove the DISTINCT keyword from
    a SELECT that forms the right-hand side of an IN operator since
    it is necessary if the SELECT also contains a LIMIT.
* Wed Oct 29 2014 andreas.stieger@gmx.de
- SQLite 3.8.7.1:
  * In PRAGMA journal_mode=TRUNCATE mode, call fsync() immediately
    after truncating the journal file to ensure that the
    transaction is durable across a power loss.
  * Fix an assertion fault that can occur when updating the NULL
    value of a field at the end of a table that was added using
    ALTER TABLE ADD COLUMN.
  * Do not attempt to use the strchrnul() function from the
    standard C library unless the HAVE_STRCHRNULL compile-time
    option is set.
  * Fix a couple of problems associated with running an UPDATE or
    DELETE on a VIEW with a rowid in the WHERE clause.
* Fri Oct 17 2014 andreas.stieger@gmx.de
- SQLite 3.8.7
- Performance Enhancements:
  * Many micro-optimizations result in 20.3%% more work for the same
    number of CPU cycles relative to the previous release.
  * The sorter can use auxiliary helper threads to increase real-
    time response. This feature is off by default and may be
    enabled using the PRAGMA threads command or the
    SQLITE_DEFAULT_WORKER_THREADS compile-time option.
  * Enhance the skip-scan optimization so that it is able to skip
    index terms that occur in the middle of the index, not just as
    the left-hand side of the index.
  * Improved optimization of CAST operators.
  * Various improvements in how the query planner uses sqlite_stat4
    information to estimate plan costs.
- New Features:
  * Added new interfaces with 64-bit length parameters:
    sqlite3_malloc64()
    sqlite3_realloc64()
    sqlite3_bind_blob64()
    sqlite3_result_blob64()
    sqlite3_bind_text64()
    sqlite3_result_text64()
  * Added the new interface sqlite3_msize() that returns the size
    of a memory allocation obtained from sqlite3_malloc64() and its
    variants.
  * Added the SQLITE_LIMIT_WORKER_THREADS option to sqlite3_limit()
    and PRAGMA threads command for configuring the number of
    available worker threads.
  * The spellfix1 extension allows the application to optionally
    specify the rowid for each INSERT. Added the User
    Authentication extension.
- Bug Fixes:
  * Fix a bug in the partial index implementation that might result
    in an incorrect answer if a partial index is used in a subquery
    or in a view.
  * Fix a query planner bug that might cause a table to be scanned
    in the wrong direction (thus reversing the order of output)
    when a DESC index is used to implement the ORDER BY clause on a
    query that has an identical GROUP BY clause.
  * Fix a bug in sqlite3_trace() that was causing it to sometimes
    fail to print an SQL statement if that statement needed to be
    re-prepared.
  * Fix a faulty assert() statement.
- Test, Debug, and Analysis Changes:
  * Show ASCII-art abstract syntax tree diagrams using the
    ".selecttrace" and ".wheretrace" commands in the command-line
    shell when compiled with SQLITE_DEBUG,
    SQLITE_ENABLE_SELECTTRACE, and SQLITE_ENABLE_WHERETRACE.
    Also provide the sqlite3TreeViewExpr() and
    sqlite3TreeViewSelect() entry points that can be invoked
    from with the debugger to show the parse tree when stopped at
    a breakpoint.
  * Drop support for SQLITE_ENABLE_TREE_EXPLAIN. The SELECTTRACE
    mechanism provides more useful diagnostics information.
  * New options to the command-line shell for configuring auxiliary
    memory usage: --pagecache, --lookaside, and --scratch.
* Fri Aug 15 2014 andreas.stieger@gmx.de
- SQLite 3.8.6
  * Added support for hexadecimal integer literals in the SQL
    parser. (Ex: 0x123abc)
  * Enhanced the PRAGMA integrity_check command to detect UNIQUE
    and NOT NULL constraint violations.
  * Increase the maximum value of SQLITE_MAX_ATTACHED from 62 to
    125.
  * Increase the timeout in WAL mode before issuing an
    SQLITE_PROTOCOL error from 1 second to 10 seconds.
  * Added the likely(X) SQL function.
  * The unicode61 tokenizer is now included in FTS4 by default.
  * Trigger automatic reprepares on all prepared statements when
    ANALYZE is run.
  * Added a new loadable extension source code file to the source
    tree: fileio.c
  * Add extension functions readfile(X) and writefile(X,Y) (using
    code copy/pasted from fileio.c in the previous bullet) to the
    command-line shell.
  * Added the .fullschema dot-command to the command-line shell.
  * performance enhancements
  * bug fixes
* Wed Jun  4 2014 andreas.stieger@gmx.de
- SQlite 3.8.5
- New and improved:
  * Added support for partial sorting by index.
  * Enhance the query planner so that it always prefers an index
    that uses a superset of WHERE clause terms relative to some
    other index.
  * Improvements to the automerge command of FTS4 to better control
    the index size for a full-text index that is subject to a large
    number of updates.
  * Added the sqlite3_rtree_query_callback() interface to R-Tree
    extension
  * Added new URI query parameters "nolock" and "immutable".
  * Use less memory by not remembering CHECK constraints on
    read-only database connections.
  * Enable the OR optimization for WITHOUT ROWID tables.
  * Render expressions of the form "x IN (?)" (with a single value
    in the list on the right-hand side of the IN operator) as if
    they where "x==?", Similarly optimize "x NOT IN (?)"
  * Add the ".system" and ".once" commands to the command-line shell
  * Added the SQLITE_IOCAP_IMMUTABLE bit to the set of bits that
    can be returned by the xDeviceCharacteristics method of a VFS.
  * Added the SQLITE_TESTCTRL_BYTEORDER test control.
- Bug Fixes:
  * OFFSET clause ignored on queries without a FROM clause.
  * Assertion fault on queries involving expressions of the form
    "x IN (?)".
  * Incorrect column datatype reported.
  * Duplicate row returned on a query against a table with more than
    16 indices, each on a separate column, and all used via OR-
    connected constraints.
  * Partial index causes assertion fault on UPDATE OR REPLACE.
  * Crash when calling undocumented SQL function
    sqlite_rename_parent() with NULL parameters.
  * ORDER BY ignored if the query has an identical GROUP BY.
  * The group_concat(x,'') SQL function returns NULL instead of an
    empty string when all inputs are empty strings.
  * Fix a bug in the VDBE code generator that caused crashes when
    doing an INSERT INTO ... SELECT statement where the number of
    columns being inserted is larger than the number of columns in
    the destination table.
  * Fix a problem in CSV import in the command-line shell where if
    the leftmost field of the first row in the CSV file was both
    zero bytes in size and unquoted no data would be imported.
  * Fix a problem in FTS4 where the left-most column that contained
    the notindexed column name as a prefix was not indexed rather
    than the column whose name matched exactly.
  * Fix the sqlite3_db_readonly() interface so that it returns
    true if the database is read-only due to the file format write
    version number being too large.
* Wed Apr 23 2014 tittiatcoke@gmail.com
- Build SQLite with the unlock_notify API, which is now required
  for the akonadi QSQLITE3 driver. "-DSQLITE_ENABLE_UNLOCK_NOTIFY"
* Thu Apr  3 2014 andreas.stieger@gmx.de
- SQLite 3.8.4.3:
  - fix for a problem that might cause incorrect query results on a
    query that mixes DISTINCT, GROUP BY in a subquery, and ORDER BY
- Fix obsolete-not-provided warning on sqlite-64bit for ppc64
* Sat Mar 29 2014 andreas.stieger@gmx.de
- SQLite 3.8.4.2:
  * Fix a potential buffer overread that could result when trying
    to search a corrupt database file.
- fix duplicate file warning on current.html on -doc package
* Wed Mar 12 2014 andreas.stieger@gmx.de
- SQLite 3.8.4.1:
  * When computing the cost of the skip-scan optimization, take
    into account the fact that multiple seeks are required.
* Mon Mar 10 2014 andreas.stieger@gmx.de
- SQLite 3.8.4
- general changes:
  * Code optimization and refactoring for improved performance.
  * Add the ".clone" and ".save" commands to the command-line shell.
  * Update the banner on the command-line shell to alert novice
    users when they are using an ephemeral in-memory database.
  * Fix editline support in the command-line shell.
  * Add support for coverage testing of VDBE programs using the
    SQLITE_TESTCTRL_VDBE_COVERAGE verb of sqlite3_test_control().
  * Update the _FILE_OFFSET_BITS macro so that builds work again on
    QNX.
  * Change the datatype of SrcList.nSrc from type u8 to type int to
    work around an issue in the C compiler on AIX.
- bug fixes:
  * Bug fix: Fix the char() SQL function so that it returns an empty
    string rather than an "out of memory" error when called with
    zero arguments.
  * Bug fix: DISTINCT now recognizes that a zeroblob and a blob of
    all 0x00 bytes are the same thing.
  * Bug fix: Compute the correct answer for queries that contain an
    IS NOT NULL term in the WHERE clause and also contain an OR term
    in the WHERE clause and are compiled with SQLITE_ENABLE_STAT4.
  * Bug fix: Make sure "rowid" columns are correctly resolved in
    joins between normal tables and WITHOUT ROWID tables.
  * Bug fix: Make sure the same temporary registers are not used
    in concurrent co-routines used to implement compound SELECT
    statements containing ORDER BY clauses, as such use can lead to
    incorrect answers.
  * Bug fix: Ensure that "ORDER BY random()" clauses do not get
    optimized out.
  * Bug fix: Repair a name-resolution error that can occur in
    sub-select statements contained within a TRIGGER.
  * Bug fix: Fix column default values expressions of the form
    "DEFAULT(-(-9223372036854775808))" so that they work correctly,
    initializing the column to a floating point value approximately
    equal to +9223372036854775808.0.
* Wed Feb 12 2014 andreas.stieger@gmx.de
- SQLite 3.8.3.1:
  * Fix a bug that causes rows to go missing on some queries with
    OR clauses and IS NOT NULL operators in the WHERE clause, when
    the SQLITE_ENABLE_STAT3 or SQLITE_ENABLE_STAT4 compile-time
    options are used.
    These compile-time options are not used in this package.
- add HTML documentation in sqlite3-doc package
* Tue Feb  4 2014 max@suse.com
- New version: 3.8.3:
  * Added support for common table expressions and the WITH
    clause.
  * Added the printf() SQL function.
  * Added SQLITE_DETERMINISTIC as an optional bit in the 4th
    argument to the sqlite3_create_function() and related
    interfaces, providing applications with the ability to create
    new functions that can be factored out of inner loops when
    they have constant arguments.
  * Add SQLITE_READONLY_DBMOVED error code, returned at the
    beginning of a transaction, to indicate that the underlying
    database file has been renamed or moved out from under SQLite.
  * Allow arbitrary expressions, including function calls and
    subqueries, in the filename argument to ATTACH.
  * Allow a VALUES clause to be used anywhere a SELECT statement
    is valid.
  * Reseed the PRNG used by sqlite3_randomness(N,P) when invoked
    with N==0. Automatically reseed after a fork() on unix.
  * Enhance the spellfix1 virtual table so that it can search
    efficiently by rowid.
  * Performance enhancements.
  * Improvements to the comments in the VDBE byte-code display
    when running EXPLAIN.
  * Add the "%%token_class" directive to LEMON parser generator and
    use it to simplify the grammar.
  * Change the LEMON source code to avoid calling C-library
    functions that OpenBSD considers dangerous. (Ex: sprintf).
  * Bug fix: In the command-line shell CSV import feature, do not
    end a field when an escaped double-quote occurs at the end of
    a CRLN line.
* Tue Jan  7 2014 max@suse.com
- Simplify building on RH for Application:Geo.
- See discussion in https://build.opensuse.org/request/show/212812
* Wed Dec 11 2013 andreas.stieger@gmx.de
- update to 3.8.2:
- adds support for WITHOUT ROWID tables
  http://sqlite.org/withoutrowid.html
- potentially incompatible change: cast from very large positive
  floating point number no longer results in most negavtive number,
  now casts from float to integers return integer closest to float
  between value and zero. Affects routines with implicit casts like
  sqlite3_column_int64()
- a number of performance enhancements
- Full list of changes: http://sqlite.org/releaselog/3_8_2.html
* Fri Oct 18 2013 kpetsch@suse.com
- New version 3.8.1:
- Full list of changes: http://sqlite.org/releaselog/3_8_1.html
- Highlights:
  * Enhancements to the query planner
  * Refactor the implementation of PRAGMA statements to improve
  parsing performance.
  * Add the "totype.c" extension, implementing the tointeger() and
  toreal() SQL functions.
  * Added the SQLITE_MINIMUM_FILE_DESCRIPTOR compile-time option
* Mon Sep 23 2013 max@suse.com
- New version 3.8.0.2:
- Full list of changes: http://sqlite.org/releaselog/3_8_0_2.html
- Highlights:
  * Add support for partial indexes.
  * Cut-over to the next generation query planner for faster and
    better query plans.
  * Added the FTS4 notindexed option, allowing non-indexed columns
    in an FTS4 table.
  * Added the SQLITE_ALLOW_URI_AUTHORITY compile-time option.
* Mon Aug 26 2013 max@suse.com
- New version 3.7.17.
- Full list of changes: http://sqlite.org/releaselog/3_7_17.html
- Highlights:
  * Add support for memory-mapped I/O.
  * Assigned the integer at offset 68 in the database header as
    the Application ID for when SQLite is used as an application
    file-format. Added the PRAGMA application_id command to query
    and set the Application ID.
  * Enhance the extension loading mechanism to be more flexible
    (while still maintaining backwards compatibility) in two ways:
    1. If the default entry point "sqlite3_extension_init" is not
    present in the loadable extension, also try an entry point
    "sqlite3_X_init" where "X" is based on the shared library
    filename. This allows every extension to have a different
    entry point, which allows them to be statically linked with
    no code changes.
    2. The shared library filename passed to
    sqlite3_load_extension() may omit the filename suffix, and
    an appropriate architecture-dependent suffix (".so",
    ".dylib", or ".dll") will be added automatically.
  * Added many new loadable extensions to the source tree,
    including amatch, closure, fuzzer, ieee754, nextchar, regexp,
    spellfix, and wholenumber.
  * Bug fix: Fix a potential database corruption bug in shared
    cache mode when one database connection is closed while
    another is in the middle of a write transaction. Ticket
    e636a050b7
* Mon Aug 12 2013 max@suse.com
- The Tcl bindings for SQLite are now part of the Tcl core, so the
  sqlite3-tcl subpackage is no longer needed.
* Wed Mar 20 2013 max@suse.com
- New Version 3.7.16:
  * Added the PRAGMA foreign_key_check command.
  * Added new extended error codes for all SQLITE_CONSTRAINT
    errors
  * Added the SQLITE_READONLY_ROLLBACK extended error code for
    when a database cannot be opened because it needs rollback
    recovery but is read-only.
  * Added SQL functions unicode(A) and char(X1,...,XN).
  * Performance improvements for PRAGMA incremental_vacuum,
    especially in cases where the number of free pages is greater
    than what will fit on a single trunk page of the freelist.
  * Improved optimization of queries containing aggregate min() or
    max().
  * Enhance virtual tables so that they can potentially use an
    index when the WHERE clause contains the IN operator.
  * Allow indices to be used for sorting even if prior terms of
    the index are constrained by IN operators in the WHERE clause.
  * Enhance the PRAGMA table_info command so that the "pk" column
    is an increasing integer to show the order of columns in the
    primary key.
  * Enhance the query optimizer to exploit transitive join
    constraints.
  * Performance improvements in the query optimizer.
  * Allow the error message from PRAGMA integrity_check to be
    longer than 20000 bytes.
  * Improved name resolution for deeply nested queries.
  * Added the test_regexp.c module as a demonstration of how to
    implement the REGEXP operator.
  * Improved error messages in the RTREE extension.
  * Enhance the command-line shell so that a non-zero argument to
    the ".exit" command causes the shell to exit immediately
    without cleanly shutting down the database connection.
  * Improved error messages for invalid boolean arguments to
    dot-commands in the command-line shell.
  * Improved error messages for "foreign key mismatch" showing the
    names of the two tables involved.
  * Remove all uses of umask() in the unix VFS.
  * Added the PRAGMA vdbe_addoptrace and PRAGMA vdbe_debug
    commands.
  * Change to use strncmp() or the equivalent instead of memcmp()
    when comparing non-zero-terminated strings.
  * Update cygwin interfaces to omit deprecated API calls.
  * Enhance the spellfix1 extension so that the edit distance cost
    table can be changed at runtime by inserting a string like
    'edit_cost_table=TABLE' into the "command" field.
  * Bug fix: repair a long-standing problem that could cause
    incorrect query results in a 3-way or larger join that
    compared INTEGER fields against TEXT fields in two or more
    places. Ticket fc7bd6358f
  * Bug fix: Issue an error message if the 16-bit reference
    counter on a view overflows due to an overly complex query.
  * Bug fix: Avoid leaking memory on LIMIT and OFFSET clauses in
    deeply nested UNION ALL queries.
  * Bug fix: Make sure the schema is up-to-date prior to running
    pragmas table_info, index_list, index_info, and
    foreign_key_list.
* Thu Jan 24 2013 max@suse.com
- New Version 3.7.15.2:
  * Added the sqlite3_errstr() interface.
  * Avoid invoking the sqlite3_trace() callback multiple times
    when a statement is automatically reprepared due to
    SQLITE_SCHEMA errors.
  * Enhance IN operator processing to make use of indices with
    numeric affinities.
  * Do full-table scans using covering indices when possible,
    under the theory that an index will be smaller and hence can
    be scanned with less I/O.
  * Enhance the query optimizer so that ORDER BY clauses are more
    aggressively optimized, especially in joins where various
    terms of the ORDER BY clause come from separate tables of the
    join.
  * Add the ability to implement FROM clause subqueries as
    coroutines rather that manifesting the subquery into a
    temporary table.
  * Several enhancements the command-line shell.
  * Added the busy_timeout pragma.
  * Added the instr() SQL function.
  * Added the SQLITE_FCNTL_BUSYHANDLER file control, used to allow
    VFS implementations to get access to the busy handler
    callback.
  * The xDelete method in the built-in VFSes now return
    SQLITE_IOERR_DELETE_NOENT if the file to be deleted does not
  * exist.
  * Bug fix: Avoid various concurrency problems in shared cache
    mode.
  * Bug fix: Avoid a deadlock or crash if the backup API, shared
    cache, and the SQLite Encryption Extension are all used at
    once.
  * Bug fix: SQL functions created using the TCL interface honor
    the "nullvalue" setting.
  * Bug fix: Fix a 32-bit overflow problem on CREATE INDEX for
    databases larger than 16GB.
  * Bug fix: Avoid segfault when using the COLLATE operator inside
    of a CHECK constraint or view in shared cache mode.
- Use %%optflags for building
- Fix debuginfo in the Tcl bindings.
* Fri Oct  5 2012 max@suse.com
- Bugfix release 3.7.14.1:
  * Fix a bug that causes a segfault on a LEFT JOIN that includes
    an OR in the ON clause.
  * Work around a bug in the optimizer in the VisualStudio-2012
    compiler that causes invalid code to be generated when
    compiling SQLite on ARM.
  * Fix the TCL interface so that the "nullvalue" setting is
    honored for TCL implementations of SQL functions.
* Tue Sep  4 2012 mmeister@suse.com
- New version 3.7.14:
  * Ensure that floating point values are preserved exactly when
    reconstructing a database from the output of the ".dump"
    command of the command-line shell.
  * Added the sqlite3_close_v2() interface.
  * Updated the command-line shell so that it can be built using
    SQLITE_OMIT_FLOATING_POINT and SQLITE_OMIT_AUTOINIT.
  * Enhancements to PRAGMA integrity_check and PRAGMA quick_check
    so that they can optionally check just a single attached
    database install of all attached databases.
  * Enhancements to WAL mode processing that ensure that at least
    one valid read-mark is available at all times, so that
    read-only processes can always read the database.
  * Performance enhancements in the sorter used by ORDER BY and CREATE INDEX.
  * Added the SQLITE_DISABLE_FTS4_DEFERRED compile-time option.
  * Better handling of aggregate queries where the aggregate
    functions are contained within subqueries.
  * Enhance the query planner so that it will try to use a
    covering index on queries that make use of or optimization.
* Fri Aug 31 2012 max@suse.com
- New version 3.7.13:
  * In-memory databases that are specified using URI filenames are
    allowed to use shared cache, so that the same in-memory
    database can be accessed from multiple database connections.
  * Recognize and use the mode=memory query parameter in URI
    filenames.
  * Avoid resetting the schema of shared cache connections when
    any one connection closes. Instead, wait for the last
    connection to close before reseting the schema.
  * In the RTREE extension, when rounding 64-bit floating point
    numbers to 32-bit for storage, always round in a direction
    that causes the bounding box to get larger.
  * Adjust the unix driver to avoid unnecessary calls to fchown().
  * Add interfaces sqlite3_quota_ferror() and
    sqlite3_quota_file_available() to the test_quota.c module.
  * The sqlite3_create_module() and sqlite3_create_module_v2()
    interfaces return SQLITE_MISUSE on any attempt to overload or
    replace a virtual table module. The destructor is always
    called in this case, in accordance with historical and current
    documentation.
* Thu May 24 2012 max@suse.com
- New version 3.7.12:
  * Add the SQLITE_DBSTATUS_CACHE_WRITE option for
    sqlite3_db_status().
  * Optimize the typeof() and length() SQL functions so that they
    avoid unnecessary reading of database content from disk.
  * Add the FTS4 "merge" command, the FTS4 "automerge" command,
    and the FTS4 "integrity-check" command.
  * Report the name of specific CHECK constraints that fail.
  * In the command-line shell, use popen() instead of fopen() if
    the first character of the argument to the ".output" command
    is "|".
  * Make use of OVERLAPPED in the windows VFS to avoid some system
    calls and thereby obtain a performance improvement.
  * More aggressive optimization of the AND operator when one side
    or the other is always false.
  * Improved performance of queries with many OR-connected terms
    in the WHERE clause that can all be indexed.
  * Add the SQLITE_RTREE_INT_ONLY compile-time option to force the
    R*Tree Extension Module to use integer instead of floating
    point values for both storage and computation.
  * Enhance the PRAGMA integrity_check command to use much less
    memory when processing multi-gigabyte databases.
  * New interfaces added to the test_quota.c add-on module.
  * Added the ".trace" dot-command to the command-line shell.
  * Allow virtual table constructors to be invoked recursively.
  * Improved optimization of ORDER BY clauses on compound queries.
  * Improved optimization of aggregate subqueries contained within
    an aggregate query.
  * Bug fix: Fix the RELEASE command so that it does not cancel
    pending queries. This repairs a problem introduced in 3.7.11.
  * Bug fix: Do not discard the DISTINCT as superfluous unless a
    subset of the result set is subject to a UNIQUE constraint and
    it none of the columns in that subset can be NULL. Ticket
    385a5b56b9.
  * Bug fix: Do not optimize away an ORDER BY clause that has the
    same terms as a UNIQUE index unless those terms are also NOT
    NULL. Ticket 2a5629202f.
- 79a4a3a84f.patch isn't needed anymore.
* Mon May 14 2012 idonmez@suse.com
- Add upstream commit 79a4a3a84f to fix subversion failures
* Fri May  4 2012 max@suse.com
- Spec file cleanup
- Drop support for the pre 11.0 packaging scheme.
- New version 3.7.11. Changes since 3.7.8 include:
  * Enhance the INSERT syntax to allow multiple rows to be inserted
    via the VALUES clause.
  * Enhance the CREATE VIRTUAL TABLE command to support the IF NOT
    EXISTS clause.
  * Added the sqlite3_stricmp() interface as a counterpart to
    sqlite3_strnicmp().
  * Added the sqlite3_db_readonly() interface.
  * Added the SQLITE_FCNTL_PRAGMA file control, giving VFS
    implementations the ability to add new PRAGMA statements or to
    override built-in PRAGMAs.
  * Queries of the form: "SELECT max(x), y FROM table" returns the
    value of y on the same row that contains the maximum x value.
  * Added support for the FTS4 languageid option.
  * Documented support for the FTS4 content option. This feature
    has actually been in the code since version 3.7.9 but is only
    now considered to be officially supported.
  * Pending statements no longer block ROLLBACK. Instead, the
    pending statement will return SQLITE_ABORT upon next access
    after the ROLLBACK.
  * Improvements to the handling of CSV inputs in the command-line
    shell
  * The default schema format number is changed from 1 to 4. This
    means that, unless the PRAGMA legacy_file_format=ON statement
    is run, newly created database files will be unreadable by
    version of SQLite prior to 3.3.0 (2006-01-10). It also means
    that the descending indices are enabled by default.
  * The sqlite3_pcache_methods structure and the
    SQLITE_CONFIG_PCACHE and SQLITE_CONFIG_GETPCACHE configuration
    parameters are deprecated. They are replaced by a new
    sqlite3_pcache_methods2 structure and SQLITE_CONFIG_PCACHE2 and
    SQLITE_CONFIG_GETPCACHE2 configuration parameters.
  * Added the powersafe overwrite property to the VFS
    interface. Provide the SQLITE_IOCAP_POWERSAFE_OVERWRITE I/O
    capability, the SQLITE_POWERSAFE_OVERWRITE compile-time option,
    and the "psow=BOOLEAN" query parameter for URI filenames.
  * Added the sqlite3_db_release_memory() interface and the
    shrink_memory pragma.
  * Added the sqlite3_db_filename() interface.
  * Added the sqlite3_stmt_busy() interface.
  * Added the sqlite3_uri_boolean() and sqlite3_uri_int64()
    interfaces.
  * If the argument to PRAGMA cache_size is negative N, that means
    to use approximately -1024*N bytes of memory for the page cache
    regardless of the page size.
  * Enhanced the default memory allocator to make use of _msize()
    on windows, malloc_size() on Mac, and malloc_usable_size() on
    Linux.
  * Enhanced the query planner to support index queries with range
    constraints on the rowid.
  * Enhanced the query planner flattening logic to allow UNION ALL
    compounds to be promoted upwards to replace a simple wrapper
    SELECT even if the compounds are joins.
  * Enhanced the query planner so that the xfer optimization can be
    used with INTEGER PRIMARY KEY ON CONFLICT as long as the
    destination table is initially empty.
  * Enhanced the windows VFS so that all system calls can be
    overridden using the xSetSystemCall interface.
  * Updated the "unix-dotfile" VFS to use locking directories with
    mkdir() and rmdir() instead of locking files with open() and
    unlink().
  * Enhancements to the test_quota.c extension to support
    stdio-like interfaces with quotas.
  * Change the unix VFS to be tolerant of read() system calls that
    return less then the full number of requested bytes.
  * Change both unix and windows VFSes to report a sector size of
    4096 instead of the old default of 512.
  * In the TCL Interface, add the -uri option to the "sqlite3" TCL
    command used for creating new database connection objects.
  * Added the SQLITE_TESTCTRL_EXPLAIN_STMT test-control option with
    the SQLITE_ENABLE_TREE_EXPLAIN compile-time option to enable
    the command-line shell to display ASCII-art parse trees of SQL
    statements that it processes, for debugging and analysis.
  * Bug fix: Add an additional xSync when restarting a WAL in order
    to prevent an exceedingly unlikely but theoretically possible
    database corruption following power-loss. Ticket ff5be73dee.
  * Bug fix: Change the VDBE so that all registers are initialized
    to Invalid instead of NULL. Ticket 7bbfb7d442
  * Bug fix: Fix problems that can result from 32-bit integer
    overflow. Ticket ac00f496b7e2
  * If a search token (on the right-hand side of the MATCH
    operator) in FTS4 begins with "^" then that token must be the
    first in its field of the document. ** Potentially Incompatible
    Change **
  * Added options SQLITE_DBSTATUS_CACHE_HIT and
    SQLITE_DBSTATUS_CACHE_MISS to the sqlite3_db_status()
    interface.
  * Removed support for SQLITE_ENABLE_STAT2, replacing it with the
    much more capable SQLITE_ENABLE_STAT3 option.
  * Enhancements to the sqlite3_analyzer utility program, including
    the --pageinfo and --stats options and support for multiplexed
    databases.
  * Enhance the sqlite3_data_count() interface so that it can be
    used to determine if SQLITE_DONE has been seen on the prepared
    statement.
  * Added the SQLITE_FCNTL_OVERWRITE file-control by which the
    SQLite core indicates to the VFS that the current transaction
    will overwrite the entire database file.
  * Increase the default lookaside memory allocator allocation size
    from 100 to 128 bytes.
  * Enhanced the query planner so that it can factor terms in and
    out of OR expressions in the WHERE clause in an effort to find
    better indices.
  * Added the SQLITE_DIRECT_OVERFLOW_READ compile-time option,
    causing overflow pages to be read directly from the database
    file, bypassing the page cache.
  * Remove limits on the magnitude of precision and width value in
    the format specifiers of the sqlite3_mprintf() family of string
    rendering routines.
  * Fix a bug that prevent ALTER TABLE ... RENAME from working on
    some virtual tables in a database with a UTF16 encoding.
  * Fix a bug in ASCII-to-float conversion that causes slow
    performance and incorrect results when converting numbers with
    ridiculously large exponents.
  * Fix a bug that causes incorrect results in aggregate queries
    that use multiple aggregate functions whose arguments contain
    complicated expressions that differ only in the case of string
  * literals contained within those expressions.
  * Fix a bug that prevented the page_count and quick_check pragmas
    from working correctly if their names were capitalized.
  * Fix a bug that caused VACUUM to fail if the count_changes
    pragma was engaged.
  * Fix a bug in virtual table implementation that causes a crash
    if an FTS4 table is dropped inside a transaction and a
    SAVEPOINT occurs afterwards.
* Thu Apr 26 2012 behrisch@users.sourceforge.net
- fixing tcl macro for old or non-SuSE builds
* Fri Oct  7 2011 max@suse.com
- New version 3.7.8:
  * Orders of magnitude performance improvement for CREATE INDEX on
    very large tables.
  * Improved the windows VFS to better defend against interference
    from anti-virus software.
  * Improved query plan optimization when the DISTINCT keyword is
    present.
  * Allow more system calls to be overridden in the unix VFS - to
    provide better support for chromium sandboxes.
  * Increase the default size of a lookahead cache line from 100 to
    128 bytes.
  * Enhancements to the test_quota.c module so that it can track
    preexisting files.
  * Bug fix: Virtual tables now handle IS NOT NULL constraints
    correctly.
  * Bug fixes: Correctly handle nested correlated subqueries used
    with indices in a WHERE clause.
- Re-integrate the Tcl bidings as a subpackage, now that it is
  easier to build both out of a single tarball.
* Thu Aug  4 2011 idonmez@novell.com
- New Version: 3.7.7.1:
  * Fix a bug causing PRAGMA case_sensitive_like statements compiled
    using sqlite3_prepare() to fail with an SQLITE_SCHEMA error.
* Fri Jun 24 2011 max@novell.com
- New Version: 3.7.7:
  * Add support for URI filenames.
  * Add the sqlite3_vtab_config() interface in support of
    ON CONFLICT clauses with virtual tables.
  * Add the xSavepoint, xRelease and xRollbackTo methods in
    virtual tables in support of SAVEPOINT for virtual tables.
  * Update the built-in FTS3/FTS4 and RTREE virtual tables to
    support ON CONFLICT clauses and REPLACE.
  * Avoid unnecessary reparsing of the database schema.
  * Added support for the FTS4 prefix option and the FTS4 order
    option.
  * Allow WAL-mode databases to be opened read-only as long as
    there is an existing read/write connection.
  * Added support for short filenames.
* Fri May 20 2011 max@novell.com
- New Version: 3.7.6.3:
  * Fix a problem with WAL mode which could cause transactions to
    silently rollback if the cache_size is set very small (less than
    10) and SQLite comes under memory pressure.
- Enabled the column metadata APIs (bnc#383370).
* Wed Apr 13 2011 max@novell.com
- New Version: 3.7.6.1:
  * Added the sqlite3_wal_checkpoint_v2() interface and enhanced
    the wal_checkpoint pragma to support blocking checkpoints.
  * Improvements to the query planner so that it makes better
    estimates of plan costs and hence does a better job of
    choosing the right plan, especially when SQLITE_ENABLE_STAT2
    is used.
  * Fix a bug which prevented deferred foreign key constraints
    from being enforced when sqlite3_finalize() was not called
    by one statement with a failed foreign key constraint prior
    to another statement with foreign key constraints running.
  * Integer arithmetic operations that would have resulted in
    overflow are now performed using floating-point instead.
  * Increased the version number on the VFS object to 3 and added
    new methods xSetSysCall, xGetSysCall, and xNextSysCall used
    for doing full-coverage testing.
  * Increase the maximum value of SQLITE_MAX_ATTACHED from 30 to
    62 (though the default value remains at 10).
  * Added the fts4aux table
  * Added support for compressed FTS4 content
  * Enhance the ANALYZE command to support the name of an index as
    its argument, in order to analyze just that one index.
  * Added the "unix-excl" built-in VFS on unix and unix-like
    platforms.
* Thu Feb  3 2011 max@novell.com
- New Version: 3.7.5:
  * Added the sqlite3_vsnprintf() interface.
  * Added the SQLITE_DBSTATUS_LOOKASIDE_HIT,
    SQLITE_DBSTATUS_LOOKASIDE_MISS_SIZE, and
    SQLITE_DBSTATUS_LOOKASIDE_MISS_FULL options for the
    sqlite3_db_status() interface.
  * Added the SQLITE_OMIT_AUTORESET compile-time option.
  * Added the SQLITE_DEFAULT_FOREIGN_KEYS compile-time option.
  * Updates to sqlite3_stmt_readonly() so that its result is
    well-defined for all prepared statements and so that it works
    with VACUUM.
  * Added the "-heap" option to the command-line shell
  * Fix a bug involving frequent changes in and out of WAL mode
    and VACUUM that could (in theory) cause database corruption.
  * Enhance the sqlite3_trace() mechanism so that nested SQL
    statements such as might be generated by virtual tables are
    shown but are shown in comments and without parameter
    expansion. This greatly improves tracing output when using the
    FTS3/4 and/or RTREE virtual tables.
  * Change the xFileControl() methods on all built-in VFSes to
    return SQLITE_NOTFOUND instead of SQLITE_ERROR for an
    unrecognized operation code.
  * The SQLite core invokes the SQLITE_FCNTL_SYNC_OMITTED file
    control to the VFS in place of a call to xSync if the database
    has PRAGMA synchronous set to OFF.
- Split off sqlite3-tcl into a separate source package.
* Thu Jan 13 2011 max@novell.com
- Adjust the package to the new upstream tarball naming and
  version numbering scheme.
- New version: 3.7.4:
  * Added the sqlite3_blob_reopen() interface to allow an
    existing sqlite3_blob object to be rebound to a new row.
  * Use the new sqlite3_blob_reopen() interface to improve the
    performance of FTS.
  * VFSes that do not support shared memory are allowed to access
    WAL databases if PRAGMA locking_mode is set to EXCLUSIVE.
  * Enhancements to EXPLAIN QUERY PLAN.
  * Added the sqlite3_stmt_readonly() interface.
  * Added PRAGMA checkpoint_fullfsync.
  * Added the SQLITE_FCNTL_FILE_POINTER option to
    sqlite3_file_control().
  * Added support for FTS4 and enhancements to the FTS matchinfo()
    function.
  * Added the test_superlock.c module which provides example code
    for obtaining an exclusive lock to a rollback or WAL database.
  * Added the test_multiplex.c module which provides an example
    VFS that provides multiplexing (sharding) of a DB, splitting
    it over multiple files of fixed size.
  * A very obscure bug associated with the or optimization was
    fixed.
* Wed Nov 17 2010 max@novell.com
- New version: 3.7.3:
  * Added the sqlite3_create_function_v2() interface that
    includes a destructor callback.
  * Added support for custom r-tree queries using
    application-supplied callback routines to define the boundary
    of the query region.
  * The default page cache strives more diligently to avoid using
    memory beyond what is allocated to it by
    SQLITE_CONFIG_PAGECACHE. Or if using page cache is allocating
    from the heap, it strives to avoid going over the
    sqlite3_soft_heap_limit64(), even if
    SQLITE_ENABLE_MEMORY_MANAGEMENT is not set.
  * Added the sqlite3_soft_heap_limit64() interface as a
    replacement for sqlite3_soft_heap_limit().
  * The ANALYZE command now gathers statistics on tables even if
    they have no indices.
  * Tweaks to the query planner to help it do a better job of
    finding the most efficient query plan for each query.
  * Enhanced the internal text-to-numeric conversion routines so
    that they work with UTF8 or UTF16, thereby avoiding some
    UTF16-to-UTF8 text conversions.
  * Fix a problem that was causing excess memory usage with large
    WAL transactions in win32 systems.
  * The interface between the VDBE and B-Tree layer is enhanced
    such that the VDBE provides hints to the B-Tree layer letting
    the B-Tree layer know when it is safe to use hashing instead
    of B-Trees for transient tables.
  * Miscellaneous documentation enhancements.
* Fri Aug 27 2010 max@novell.com
- New version: 3.7.2:
  * Added new commands SQLITE_DBSTATUS_SCHEMA_USED and
    SQLITE_DBSTATUS_STMT_USED to the sqlite3_db_status()
    interface, in order to report out the amount of memory used
    to hold the schema and prepared statements of a connection.
  * Increase the maximum size of a database pages from 32KiB to
    64KiB.
  * Use the LIKE optimization even if the right-hand side string
    contains no wildcards.
  * Added the SQLITE_FCNTL_CHUNK_SIZE verb to the
    sqlite3_file_control() interface for both unix and windows, to
    cause database files to grow in large chunks in order to reduce
    disk fragmentation.
  * Fixed a bug in the query planner that caused performance
    regresssions relative to 3.6.23.1 on some complex joins.
  * Fixed a typo in the OS/2 backend.
  * Refactored the pager module.
  * The SQLITE_MAX_PAGE_SIZE compile-time option is now silently
    ignored. The maximum page size is hard-coded at 65536 bytes.
  * Fix an old and very obscure bug that can lead to corruption of
    the database free-page list when incremental_vacuum is used.
* Thu Aug  5 2010 max@suse.de
- New version 3.7.0.1:
  * Fix a potential database corruption problem that can result
    if the same database file is alternately written by version
    3.7.0 and 3.6.23.1.
  * Fix a possible performance regression caused by the
    introduction of automatic indexing.
* Thu Jul 22 2010 max@suse.de
- New version: 3.7.0:
  * Added support for write-ahead logging.
  * Query planner enhancement - automatic transient indices are
    created when doing so reduces the estimated query time.
  * Query planner enhancement - the ORDER BY becomes a no-op if
    the query also contains a GROUP BY clause that forces the
    correct output order.
  * Add the SQLITE_DBSTATUS_CACHE_USED verb for
    sqlite3_db_status().
  * The logical database size is now stored in the database
    header so that bytes can be appended to the end of the
    database file without corrupting it and so that SQLite will
    work correctly on systems that lack support for ftruncate().
* Mon Jul  5 2010 max@suse.de
- Bugfix release: 3.6.23.1
  * Fix a bug in the offsets() function of FTS3.
  * Fix a missing "sync" that when omitted could lead to database
    corruption if a power failure or OS crash occurred just as a
    ROLLBACK operation was finishing.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Mar 10 2010 max@suse.de
- Version 3.6.23:
  * Added the secure_delete pragma.
  * Added the sqlite3_compileoption_used() and
    sqlite3_compileoption_get() interfaces as well as the
    compile_options pragma and the sqlite_compileoption_used() and
    sqlite_compileoption_get() SQL functions.
  * Added the sqlite3_log() interface together with the
    SQLITE_CONFIG_LOG verb to sqlite3_config(). The ".log" command
    is added to the Command Line Interface.
  * Improvements to FTS3.
  * Improvements and bug-fixes in support for
    SQLITE_OMIT_FLOATING_POINT.
  * The integrity_check pragma is enhanced to detect out-of-order
    rowids.
  * The ".genfkey" operator has been removed from the Command Line
    Interface.
  * Updates to the co-hosted Lemon LALR(1) parser
    generator. (These updates did not effect SQLite.)
  * Various minor bug fixes and performance enhancements.
* Wed Jan 20 2010 max@suse.de
- Add -fno-strict-aliasing to CFLAGS as a temporary workaround
  for a crash on (at least) PPC (bnc#571934).
* Thu Jan 14 2010 max@novell.com
- New version: 3.6.22:
  * Fix bugs that can (rarely) lead to incorrect query results
    when the CAST or OR operators are used in the WHERE clause of
    a query.
  * Continuing enhancements and improvements to FTS3.
  * The SQL output resulting from sqlite3_trace() is now modified
    to include the values of bound parameters.
  * Performance optimizations targetting a specific use case from
    a single high-profile user of SQLite. A 12%% reduction in the
    number of CPU operations is achieved (as measured by
    valgrind). Actual performance improvements in practice may
    vary depending on workload. Changes include:
  * The ifnull() and coalesce() SQL functions are now
    implemented using in-line VDBE code rather than calling
    external functions, so that unused arguments need never be
    evaluated.
  * The substr() SQL function does not bother to measure the
    length its entire input string if it is only computing a
    prefix.
  * Unnecessary OP_IsNull, OP_Affinity, and OP_MustBeInt VDBE
    opcodes are suppressed.
  * Various code refactorizations for performance.
  * The FTS3 extension has undergone a major rework and
    cleanup. New FTS3 documentation is now available.
  * The SQLITE_SECURE_DELETE compile-time option fixed to make
    sure that content is deleted even when the truncate
    optimization applies.
  * Improvements to "dot-command" handling in the Command Line
    Interface.
  * Other minor bug fixes and documentation enhancements.
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Nov 30 2009 max@suse.de
- New version: 3.6.20.
- Reworked package to use the "amalgamation" source distribution
  as recommended by the author and to fix the following bugs:
  * bnc#555845: sqlite3 should link libdl
  * bnc#470371: system sqlite should be built with fts3
* Thu Oct 22 2009 andrea@opensuse.org
- enabled load-extension option since some packages need
  such symbol
* Wed Aug  5 2009 max@suse.de
- New version: 3.6.16:
  * Fix a bug (ticket #3929) that occasionally causes INSERT or
    UPDATE operations to fail on an indexed table that has a
    self-modifying trigger.
  * Refactor the internal representation of SQL expressions so
    that  they use less memory on embedded platforms.
  * Reduce the amount of stack space used
  * The sqlite3_create_function() family of interfaces now return
    SQLITE_MISUSE instead of SQLITE_ERROR when passed invalid
    parameter combinations.
  * When new tables are created using CREATE TABLE ... AS SELECT
    ... the datatype of the columns is the simplified SQLite
    datatype (TEXT, INT, REAL, NUMERIC, or BLOB) instead of a
    copy of the original datatype from the source table.
  * Resolve race conditions when checking for a hot rollback
    journal.
  * The sqlite3_shutdown() interface frees all mutexes under
    windows.
  * Enhanced robustness against corrupt database files
  * Continuing improvements to the test suite and fixes to
    obscure bugs and inconsistencies that the test suite
    improvements are uncovering.
  * Other minor bug fixes and performance optimizations.
* Tue Jun  2 2009 max@suse.de
- New version 3.6.14.2:
  * Fix a code generator bug introduced in version 3.6.14. This bug
    can cause incorrect query results under obscure circumstances.
- Use the old naming scheme when building on openSUSE < 11.0.
* Sun Feb 22 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Oct 24 2008 max@suse.de
- Update to version 3.6.4:
  * Fixes a missing symbol with the Tcl binding.
  * Added the sqlite3_stmt_status() interface for performance
    monitoring.
  * Added the TRUNCATE option to PRAGMA journal_mode
  * Performance enhancements to tree balancing logic in the B-Tree
    layer.
  * Added the source code and documentation for the genfkey
    program for automatically generating triggers to enforce
    foreign key constraints.
  * The SQL language documentation is converted to use syntax
    diagrams instead of BNF.
  * Other minor bug fixes
* Fri Sep 26 2008 max@suse.de
- Bugfix-Release 3.6.3:
  * Fix for a bug in the SELECT DISTINCT logic that was introduced
    by the prior versoin.
  * Other minor bug fixes.
* Wed Sep 10 2008 max@suse.de
- Update to version 3.6.2.
- This version contains rewrites of the page-cache subsystem and
  the procedures for matching identifiers to table columns in SQL
  statements. These changes are designed to better modularize the
  code and make it more maintainable and reliable moving forward.
  Nearly 5000 non-comment lines of core code (about 11.3%%) have
  changed from the previous release. Nevertheless, there should
  be no application-visible changes, other than bug fixes.
* Fri Jul 25 2008 max@suse.de
- Update to version 3.6.0:
  * Modifications to the virtual file system interface to support a
    wider range of embedded systems. See 35to36.html for additional
    information. *** Potentially incompatible change ***
  * The handling of IN and NOT IN operators that contain a NULL on
    their right-hand side expression is brought into compliance with
    the SQL standard and with other SQL database engines. This is a
    bug fix, but as it has the potential to break legacy applications
    that depend on the older buggy behavior, we mark that as a
  * ** Potentially incompatible change ***
  * The result column names generated for compound subqueries have
    been simplified to show only the name of the column of the
    original table and omit the table name. This makes SQLite
    operate more like other SQL database engines.
  * Added the sqlite3_config() interface for doing run-time
    configuration of the entire SQLite library.
  * Added the sqlite3_status() interface used for querying run-time
    status information about the overall SQLite library and its
    subsystems.
  * Added the sqlite3_initialize() and sqlite3_shutdown() interfaces.
  * The SQLITE_OPEN_NOMUTEX option was added to sqlite3_open_v2().
  * Added the PRAGMA page_count command.
  * Added the sqlite3_next_stmt() interface.
  * Added a new R*Tree virtual table
- Link libtclsqlite against the Tcl stubs library, so that it can be
  used from tclkit.
* Thu May  8 2008 max@suse.de
- Actually apply sqlite-strcasecmp.patch to fix the Tcl extension.
- Link the Tcl extension dynamically.
* Wed May  7 2008 coolo@suse.de
- provide sqlite-<arch>
* Tue Apr 29 2008 cthiel@suse.de
- obsolete sqlite-<arch> via baselibs.conf
* Mon Apr 28 2008 max@suse.de
- Avoid an unresolved symbol in the Tcl extension
  (sqlite-strcasecmp.patch).
- Use upstream fixes for test failures caused by Tcl 8.5
* Sun Apr 27 2008 coolo@suse.de
- disable the test suite, it adds 5 hours to the build time
* Thu Apr 10 2008 max@suse.de
- update to version 3.5.7. Changes include:
  * Fix a bug in the register allocation for compound selects.
  * Do not apply the flattening optimization if the outer query
    is an aggregate and the inner query contains ORDER BY.
  * Accept "Z" as the zulu timezone at the end of date strings.
  * Fix a bug in the LIKE optimizer that occurs when the last
    character before the first wildcard is an upper-case "Z"
  * Added the "bitvec" object for keeping track of which pages
    have been journalled. Improves speed and reduces memory
    consumption, especially for large database files.
  * Add the new sqlite3_result_error_code() API.
  * Convert the underlying virtual machine to be a register-based
    machine rather than a stack-based machine. The only
    user-visible change is in the output of EXPLAIN.
- Fix build for Tcl 8.5.
- Don't --enable-releasemode anymore, because it recently started
  putting the package version into the library name
  (libsqlite3-3.5.7.so.0.8.6)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 max@suse.de
- Fixed the tcl subpackage and adapted it to the new Tcl file
  system layout.
* Thu Jan 10 2008 lrupp@suse.de
- split of libsqlite3-0 package (Shared Library Packaging Policy)
- rename sqlite to sqlite3
* Tue Dec 18 2007 adrian@suse.de
- update to version 3.5.4
  From official changelog:
  * Fix a critical bug in UPDATE or DELETE that occurs when an
    OR REPLACE clause or a trigger causes rows in the same table to be
    deleted as side effects. (See ticket #2832.) The most likely result
    of this bug is a segmentation fault, though database corruption is
    a possibility.
  * Bring the processing of ORDER BY into compliance with the SQL
    standard for case where a result alias and a table column name are
    in conflict. Correct behavior is to prefer the result alias. Older
    versions of SQLite incorrectly picked the table column. (See ticket #2822.)
  * The VACUUM command preserves the setting of the legacy_file_format
    pragma. (Ticket #2804.)
  * Productize and officially support the group_concat() SQL function.
  * Better optimization of some IN operator expressions.
  * Add the ability to change the auto_vacuum status of a database by
    setting the auto_vaccum pragma and VACUUMing the database.
  * Prefix search in FTS3 is much more efficient.
  * Relax the SQL statement length restriction in the CLI so that the
    ".dump" output of databases with very large BLOBs and strings can
    be played back to recreate the database.
  * Other small bug fixes and optimizations.
* Fri Nov 30 2007 adrian@suse.de
- update to version 3.5.3
  * documentation has been removed from tar ball.
  From official changelog:
  * Fix a long-standing bug in INSERT INTO ... SELECT ... statements
    where the SELECT is compound.
  * Fix a long-standing bug in RAISE(IGNORE) as used in BEFORE triggers.
  * Fixed the operator precedence for the ~ operator.
  * Allow collating sequence names to be quoted.
  * Modify the TCL interface to use sqlite3_prepare_v2().
  * Fix multiple bugs that can occur following a malloc() failure.
  * sqlite3_step() returns SQLITE_MISUSE instead of crashing when
    called with a NULL parameter.
  * FTS3 now uses the SQLite memory allocator exclusively. The FTS3
    amalgamation can now be appended to the SQLite amalgamation to
    generate a super-amalgamation containing both.
  * The DISTINCT keyword now will sometimes use an INDEX if an
    appropriate index is available and the optimizer thinks its use
    might be advantageous.
* Mon Nov  5 2007 adrian@suse.de
- update to version 3.5.2
  From the official changelog:
  * The OS interface layer and the memory allocation subsystems in
    SQLite have been reimplemented. The published API is largely
    unchanged but the (unpublished) OS interface has been modified
    extensively. Applications that implement their own OS interface
    will require modification.
  * This is a large change. Approximately 10%% of the source code was
    modified.
  * Fix a long-standing bug that might cause database corruption if
    a disk-full error occurs in the middle of a transaction and that
    transaction is not rolled back.
* Thu Oct 18 2007 sbrabec@suse.cz
- Build with column metadata support, as required by libgda.
* Mon Aug 13 2007 adrian@suse.de
- call %%post/%%pre ldconfig again (#298292)
* Mon Aug  6 2007 adrian@suse.de
- update to version 3.4.1
  * Bugfix release to solve database corruption
  * remove static fts2 plugin patch, it is broken and get not used
  * Changelog from the release:
  - Fix a bug in VACUUM that can lead to  database corruption if two
    processes are connected to the database at the same time and one
    VACUUMs then the other then modifies the database.
  - The expression "+column" is now considered the same as "column" when
    computing the collating sequence to use on the expression.
  - In the TCL language interface, "@variable" instead of "$variable" always
    binds as a blob.
  - Added PRAGMA freelist_count for determining the current size of the
    freelist.
  - The  PRAGMA auto_vacuum=incremental setting is now persistent.
  - Add FD_CLOEXEC to all open files under unix.
  - Fix a bug in the  min()/max() optimization when applied to descending
    indices.
  - Make sure the TCL language interface works correctly with 64-bit integers
    on 64-bit machines.
  - Allow the value -9223372036854775808 as an integer literal in SQL
    statements.
  - Add the capability of "hidden" columns in virtual tables.
  - Use the macro SQLITE_PRIVATE (defaulting to "static") on all internal
    functions in the amalgamation.
  - Add pluggable tokenizers and ICU tokenization support to FTS2
  - Other minor bug fixes and documentation enhancements
* Tue Jun 26 2007 adrian@suse.de
- update to version 3.4.0
  WARNING: this version might cause incompatibilities due to new
    limits. These limits could be raised again, if we run in
    trouble, but let's follow upstream for now.
  * Two important bugfixes for database corruption.
  * New features like incremental BLOB I/O and incremental vacuum
* Fri Apr 27 2007 adrian@suse.de
- update to version 3.3.17
  * bug fix in forwards-compatibility logic of SQLite
* Thu Apr 19 2007 adrian@suse.de
- update to version 3.3.16
  * speed improvements were not enabled in .15 by accident
* Mon Apr 16 2007 adrian@suse.de
- update to version 3.3.15
  * speed improvements
  * new exclusive locking mode
- switch to -O3 now
- general spec file clean up
* Mon Feb 19 2007 adrian@suse.de
- update to version 3.3.13
  from the changelog:
  * Add a "fragmentation" measurement in the output of sqlite3_analyzer.
  * Add the COLLATE operator used to explicitly set the collating
    sequence used by an expression. This feature is considered
    experimental pending additional testing.
  * Allow up to 64 tables in a join - the old limit was 32.
  * Added two new experimental functions: randomBlob() and hex().
    Their intended use is to facilitate generating UUIDs.
  * Fix a problem where PRAGMA count_changes was causing incorrect
    results for updates on tables with triggers
  * Fix a bug in the ORDER BY clause optimizer for joins where
    the left-most table in the join is constrained by a UNIQUE index.
  * Fixed a bug in the "copy" method of the TCL interface.
  * Bug fixes in fts1 and fts2 modules.
* Mon Feb 12 2007 dmueller@suse.de
- fix library dependencies after loadable extensions were enabled
* Tue Feb  6 2007 dmacvicar@suse.de
- Enable support for loadable extensions
* Mon Feb  5 2007 max@suse.de
- Enable the fts1 and fts2 modules and link them in statically.
* Wed Jan 31 2007 adrian@suse.de
- update to version 3.3.12
  * further bugfixes, esp. for bugs introduced in 3.3.9
* Thu Jan 11 2007 adrian@suse.de
- update to version 3.3.10
  * pure bug fix release
* Tue Jan  9 2007 adrian@suse.de
- update to version 3.3.9
  * fixes database corruption "under obscure and difficult to
    reproduce circumstances".
  * new sqlite3_prepare v2() api (new header file)
* Mon Nov  6 2006 adrian@suse.de
- fix permissions of installed man page
* Mon Oct 16 2006 adrian@suse.de
- update to version 3.3.8
  * full-text search using the FTS1 module
  * minor bufixes
- two testcases got disabled, because they fail.
  We need to review the reason for that before shipping this package,
  but this package builds again at least.
* Wed Aug 23 2006 adrian@suse.de
- update to version 3.3.7
  * support for loadable extensions and virtual tables
  * minor bugfixes
* Thu May 18 2006 adrian@suse.de
- update to version 3.3.5
  Version 3.3 adds support for CHECK constraints, DESC indices,
  separate REAL and INTEGER column affinities, a new OS interface
  layer design, and many other changes.
  The file format for version 3.3 has changed slightly. SQLite 3.3
  will read and write legacy databases created with any prior
  version of SQLite 3. But databases created by version 3.3.0 will
  not be readable or writable by earlier versions of the SQLite
* Wed Mar 22 2006 schwab@suse.de
- Fix another 64bit bug.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 adrian@suse.de
- disable "same thread check". It is only needed with broken
  thread implementations and will be similar offered in sqlite 3.3
* Wed Jan  4 2006 adrian@suse.de
- update to version 3.2.8
  * bugfix release
* Tue Jan  3 2006 rguenthe@suse.de
- Correct 64bit issues causing x86_64 testsuite failures.
* Fri Dec  2 2005 jw@suse.de
- VERSION parsing back to normal.
  3002007 looks better than 3000000
* Mon Oct 24 2005 adrian@suse.de
- fix build for 64bit
* Mon Oct 17 2005 adrian@suse.de
- update to version 3.2.7
  * needed an additional fix for conflict.test
* Tue Aug 30 2005 jw@suse.de
- disabled a timing test. This fixes failed builds
  on heavy loaded autobuild hosts.
* Wed Jun 29 2005 jw@suse.de
- configure script fixed: VERSION was misparsed.
* Mon Jun 27 2005 max@suse.de
- Skip the testsuite if the underlaying file system doesn't
  support fsync() on directories (e.g. tmpfs).
* Tue Jun 21 2005 max@suse.de
- Update to version 3.2.2.
- Improved installation of the Tcl package.
* Thu Apr 21 2005 max@suse.de
- Disabling of certain tests for certain architectures does not
  seem to be needed anymore.
* Tue Apr 19 2005 ro@suse.de
- get patch to even apply
* Tue Apr 19 2005 max@suse.de
- Added a subpackage for the Tcl extension.
* Fri Apr  8 2005 adrian@suse.de
- update to version 3.2.1
* Tue Mar 29 2005 adrian@suse.de
- update to version 3.2.0
* Mon Feb 28 2005 adrian@suse.de
- update to version 3.1.3
  * a minor bugfix for VACUUM databases
  * to remain compatible with future 3.2 databases
- obsoletes a testsuite workaround
* Fri Feb 18 2005 adrian@suse.de
- fix library versioning
* Wed Feb 16 2005 adrian@suse.de
- update to version 3.1.2
  * contains a criticial bugsfix, which can corrupted the database
    when using the VACUUM command
* Mon Nov 29 2004 adrian@suse.de
- update to version 3.0.8
* Mon Nov 15 2004 adrian@suse.de
- add susehelp desktop file for developer documentation
* Mon Nov 15 2004 adrian@suse.de
- fix libdir path in .la file for lib64 systems
* Mon Oct 25 2004 adrian@suse.de
- enable utf-8 support
* Fri Jul 30 2004 adrian@suse.de
- run "make alltest"
* Thu Jul 29 2004 adrian@suse.de
- update to version 2.8.15
- disable wrong tcl test case on 64bit
* Mon Jun 21 2004 adrian@suse.de
- update to version 2.8.14
* Tue Jun  1 2004 adrian@suse.de
- package sqlite man page
* Fri Apr 23 2004 adrian@suse.de
- update to version 2.8.13
* Mon Mar  1 2004 adrian@suse.de
- disable format3 test case for ppc for now
* Sun Feb 29 2004 adrian@suse.de
- update to version 2.8.12
- add usual 64bit fixes
- add -fno-strict-aliasing
- disable bigfile test case due to limits in autobuild
* Thu Jan 22 2004 adrian@suse.de
- update to version 2.8.11
  * one testcase fails on ppc, our ppc people will have a look
* Mon Dec 29 2003 adrian@suse.de
- update to version 2.8.8
  * several 64 bit fixes have been merged, some more are needed now
- ignore some not exact matching float test cases on s390*
- enable threading support
* Tue Dec  2 2003 adrian@suse.de
- initial package of version 2.8.6
- a number of 64bit fixes
- some test cases got disabled, because they use an invalid Tcl
  Interface for 64bit
